summaryrefslogtreecommitdiffstats
path: root/src/autodimm.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/autodimm.h')
-rw-r--r--src/autodimm.h7
1 files changed, 4 insertions, 3 deletions
diff --git a/src/autodimm.h b/src/autodimm.h
index ace1e08..161c776 100644
--- a/src/autodimm.h
+++ b/src/autodimm.h
@@ -38,6 +38,7 @@
class autodimm : public inactivity
{
Q_OBJECT
+ TQ_OBJECT
public:
//! default constructor
@@ -56,19 +57,19 @@ private:
//! idle time from the last check
unsigned long lastIdleTime;
//! QTimer intervall for the Timer to recheck for user activity
/*!
* The time intervall to recheck for the activity of the user.
* The timeslice is currently 1 sec.
*/
static const int RECHECK_INTERVALL = 1000;
//! QTimer for check activity
/*!
* This timer is used to check if the user get active again.
* The timerinterval is defined trough \ref RECHECK_INTERVALL .
*/
- QTimer *checkActivity;
+ TQTimer *checkActivity;
private slots:
//! to poll X to get info if the user is active again
@@ -56,19 +57,19 @@ private:
//! idle time from the last check
unsigned long lastIdleTime;
- //! QTimer intervall for the Timer to recheck for user activity
+ //! TQTimer intervall for the Timer to recheck for user activity
/*!
* The time intervall to recheck for the activity of the user.
@@ -56,19 +57,19 @@ private:
*/
static const int RECHECK_INTERVALL = 1000;
- //! QTimer for check activity
+ //! TQTimer for check activity
/*!
* This timer is used to check if the user get active again.